"""
Async example using Claude with tool calls.
"""

import asyncio

from agentverse_ai.agent import Agent
from agentverse_ai.models.aws import Claude
from agentverse_ai.tools.duckduckgo import DuckDuckGoTools

agent = Agent(
    model=Claude(id="anthropic.claude-3-5-sonnet-20240620-v1:0"),
    tools=[DuckDuckGoTools()],
    show_tool_calls=True,
    markdown=True,
)

asyncio.run(agent.aprint_response("Whats happening in France?", stream=True))
